package be.cylab.java.roc;

/**
 * Class to represent coordinates in the Roc space.
 * For a Roc curve, x_axis is false_alarm.
 * For a Roc curve, y_axis is true_detection.
 * For a P-R curve, x_axis is recall.
 * For a P-R curve, y_axis is precision.
 */
public class CurveCoordinates {

    private double x_axis;
    private double y_axis;

    /**
     * Constructor of RocCoordinate object.
     * @param x_axis double false_alarm for ROC - Recall for P-R curve
     * @param y_axis double true_detection for ROC - Precision for P-R curve
     */
    public CurveCoordinates(final double x_axis,
                            final double y_axis) {
        this.setXAxis(x_axis);
        this.setYAxis(y_axis);
    }

    /**
     * Getter for False alarm.
     * @return
     */
    public final double getXAxis() {
        return x_axis;
    }

    /**
     * Setter for False Alarm.
     * @param x_axis
     */
    public final void setXAxis(final double x_axis) {
        if (x_axis < 0 || x_axis > 1) {
            throw new IllegalArgumentException(""
                    + "Value must be between 0 and 1");
        }
        this.x_axis = x_axis;
    }

    /**
     * Getter for true detection.
     * @return
     */
    public final double getYAxis() {
        return y_axis;
    }

    /**
     * Setter for True Detection.
     * @param y_axis
     */
    public final void setYAxis(final double y_axis) {
        if (y_axis < 0 || y_axis > 1) {
            throw new IllegalArgumentException(
                    "Value must be between 0 and 1");
        }
        this.y_axis = y_axis;
    }
}
